@@ -6,9 +6,10 @@ use JSON::XS;
 use YAML::XS qw/LoadFile/;
 use Path::Class qw/file/;
 use Data::Dumper;
+use Time::HiRes qw/sleep/;
 use v5.14;
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 has url      => 'http://localhost:3000';
 has 'key';
@@ -40,6 +41,7 @@ sub get {
     my $s = shift;
     my $path = shift;
     if (defined($s->delay)) {
+        $s->logger->debug("sleeping for ".$s->delay.'s');
         sleep $s->delay;
     }
     my $tx = $s->ua->get($s->url."$path");
